use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006002
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
Stevan
Little
stevan
Infinity
Interactive
Inc
Brandon
Black
blblack
Chris
Prather
chris
Dagfinn
Ilmari
Mannsåker
ilmari
Damien
Krotkine
dkrotkine
Devin
Austin
devin
Drew
Taylor
drew
Florian
Ragwitz
rafl
Gordon
Irving
goraxe
Hans
Dieter
Pearcey
hdp
Hinrik
Örn
Sigurðsson
hinrik
Jesse
Luehrs
doy
John
Goulah
jgoulah
Jonathan
Swartz
swartz
Justin
Hunter
justin
Karen
Etheridge
ether
Nelo
Onyiah
nelo
Ricardo
SIGNES
rjbs
Ryan
Johnson
ryan
Shlomi
Fish
shlomif
Todd
Hepler
thepler
Tomas
Doran
bobtfish
Yuval
Kogman
nothingmuch
Ævar
Arnfjörð
Bjarmason
avarab
lib
MooseX
Getopt
Meta
Attribute
Trait
Strict
NoGetopt
Basic
Dashes
ProcessedArgv
OptionTypeMap
GLD
